<?php
/**
 * sprouts functions and definitions
 *
 * @package sprouts
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 640; /* pixels */
}

if ( ! function_exists( 'sprouts_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function sprouts_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on sprouts, use a find and replace
	 * to change 'sprouts' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'sprouts', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	//add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'sprouts' ),
		'top' => __('Top Menu', 'sprouts'),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'quote', 'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'sprouts_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
	
	/**
	* Enable support for featured images.
	*/
	add_theme_support( 'post-thumbnails' ); 
	add_image_size('sprouts-home-thumb',400,300, true);

}
endif; // sprouts_setup
add_action( 'after_setup_theme', 'sprouts_setup' );

function sprouts_customizer($wp_customize) {

	$wp_customize-> add_section(
    'sprouts-sec1',
    array(
    	'title'			=> __('Social Settings','sprouts'),
    	'description'	=> __('Manage the Social Icon Setings of your site.','sprouts'),
    	'priority'		=> 3,
    	)
    );
    
    $wp_customize-> add_setting(
    'sprouts-social',
    array(
    	'default'			=> false,
    	'sanitize_callback'	=> 'sprouts_sanitize_checkbox',
    	)
    );
    
    $wp_customize-> add_control(
    'sprouts-social',
    array(
    	'type'		=> 'checkbox',
    	'label'		=> __('Enable Social Icons','sprouts'),
    	'section'	=> 'sprouts-sec1',
    	'priority'	=> 1,
    	)
    );

    $wp_customize-> add_setting(
    'sprouts-facebook',
    array(
    	'default'	=> '',
    	'sanitize_callback' => 'esc_url_raw',
    	)
    );
    
    $wp_customize-> add_control(
    'sprouts-facebook',
    array(
    	'label'		=> __('Facebook URL','sprouts'),
    	'section'	=> 'sprouts-sec1',
    	'type'		=> 'text',
    	)
    );
    
    $wp_customize-> add_setting(
    'sprouts-twitter',
    array(
    	'default'	=> '',
    	'sanitize_callback' => 'esc_url_raw',
    	)
    );
    
    $wp_customize-> add_control(
    'sprouts-twitter',
    array(
    	'label'		=> __('Twitter URL','sprouts'),
    	'section'	=> 'sprouts-sec1',
    	'type'		=> 'text',
    	)
    );
    
    $wp_customize-> add_setting(
    'sprouts-google-plus',
    array(
    	'default'	=> '',
    	'sanitize_callback' => 'esc_url_raw',
    	)
    );
    
    $wp_customize-> add_control(
    'sprouts-google-plus',
    array(
    	'label'		=> __('Google Plus URL','sprouts'),
    	'section'	=> 'sprouts-sec1',
    	'type'		=> 'text',
    	)
    );
    
    $wp_customize-> add_setting(
    'sprouts-instagram',
    array(
    	'default'	=> '',
    	'sanitize_callback' => 'esc_url_raw',
    	)
    );
    
    $wp_customize-> add_control(
    'sprouts-instagram',
    array(
    	'label'		=> __('Instagram URL','sprouts'),
    	'section'	=> 'sprouts-sec1',
    	'type'		=> 'text',
    	)
    );
    
    $wp_customize-> add_setting(
    'sprouts-pinterest-p',
    array(
    	'default'	=> '',
    	'sanitize_callback' => 'esc_url_raw',
    	)
    );
    
    $wp_customize-> add_control(
    'sprouts-pinterest-p',
    array(
    	'label'		=> __('Pinterest URL','sprouts'),
    	'section'	=> 'sprouts-sec1',
    	'type'		=> 'text',
    	)
    );
    
    $wp_customize-> add_setting(
    'sprouts-youtube',
    array(
    	'default'	=> '',
    	'sanitize_callback' => 'esc_url_raw',
    	)
    );
    
    $wp_customize-> add_control(
    'sprouts-youtube',
    array(
    	'label'		=> __('Youtube URL','sprouts'),
    	'section'	=> 'sprouts-sec1',
    	'type'		=> 'text',
    	)
    );
    
    $wp_customize-> add_setting(
    'sprouts-vimeo-square',
    array(
    	'default'	=> '',
    	'sanitize_callback' => 'esc_url_raw',
    	)
    );
    
    $wp_customize-> add_control(
    'sprouts-vimeo-square',
    array(
    	'label'		=> __('Vimeo URL','sprouts'),
    	'section'	=> 'sprouts-sec1',
    	'type'		=> 'text',
    	)
    );
    
    $wp_customize-> add_setting(
    'sprouts-envelope-o',
    array(
    	'default'	=> '',
    	'sanitize_callback' => 'esc_url_raw',
    	)
    );
    
    $wp_customize-> add_control(
    'sprouts-envelope-o',
    array(
    	'label'		=> __('Your E-Mail Info','sprouts'),
    	'section'	=> 'sprouts-sec1',
    	'type'		=> 'text',
    	)
    );
    
    $wp_customize-> add_setting(
    'sprouts-tumblr',
    array(
    	'default'	=> '',
    	'sanitize_callback' => 'esc_url_raw',
    	)
    );
    
    $wp_customize-> add_control(
    'sprouts-tumblr',
    array(
    	'label'		=> __('Tumblr URL','sprouts'),
    	'section'	=> 'sprouts-sec1',
    	'type'		=> 'text',
    	)
    );
    
    $wp_customize-> add_setting(
    'sprouts-stumbleupon',
    array(
    	'default'	=> '',
    	'sanitize_callback' => 'esc_url_raw',
    	)
    );
    
    $wp_customize-> add_control(
    'sprouts-stumbleupon',
    array(
    	'label'		=> __('StumbleUpon URL','sprouts'),
    	'section'	=> 'sprouts-sec1',
    	'type'		=> 'text',
    	)
    );
    
    $wp_customize-> add_setting(
    'sprouts-reddit',
    array(
    	'default'	=> '',
    	'sanitize_callback' => 'esc_url_raw',
    	)
    );
    
    $wp_customize-> add_control(
    'sprouts-reddit',
    array(
    	'label'		=> __('Reddit URL','sprouts'),
    	'section'	=> 'sprouts-sec1',
    	'type'		=> 'text',
    	)
    );
    
    $wp_customize-> add_setting(
    'sprouts-vine',
    array(
    	'default'	=> '',
    	'sanitize_callback' => 'esc_url_raw',
    	)
    );
    
    $wp_customize-> add_control(
    'sprouts-vine',
    array(
    	'label'		=> __('Vine URL','sprouts'),
    	'section'	=> 'sprouts-sec1',
    	'type'		=> 'text',
    	)
    );
    
    $wp_customize-> add_setting(
    'sprouts-soundcloud',
    array(
    	'default'	=> '',
    	'sanitize_callback' => 'esc_url_raw',
    	)
    );
    
    $wp_customize-> add_control(
    'sprouts-soundcloud',
    array(
    	'label'		=> __('SoundCloud URL','sprouts'),
    	'section'	=> 'sprouts-sec1',
    	'type'		=> 'text',
    	)
    );
    
    $wp_customize-> add_setting(
    'sprouts-yelp',
    array(
    	'default'	=> '',
    	'sanitize_callback' => 'esc_url_raw',
    	)
    );
    
    $wp_customize-> add_control(
    'sprouts-yelp',
    array(
    	'label'		=> __('Yelp URL','sprouts'),
    	'section'	=> 'sprouts-sec1',
    	'type'		=> 'text',
    	)
    );
    
    $wp_customize-> add_panel(
    'sprouts-slider', array(
    'priority'       => 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '',
    'title'          => __('Slider Settings', 'sprouts'),
    'description'    => '',
    ));
    
    $wp_customize-> add_section(
    'sprouts-slides',
    array(
    	'title'			=> __('Enable Slider','sprouts'),
    	'priority'		=> 3,
    	'panel'			=> 'sprouts-slider',
    	)
    );
    
    $wp_customize-> add_setting(
    'sprouts-slide-enable',
    array(
    	'default'			=> false,
    	'sanitize_callback'	=> 'sprouts_sanitize_checkbox',
    	)
    );
    
    $wp_customize-> add_control(
    'sprouts-slide-enable',
    array(
    	'type'		=> 'checkbox',
    	'label'		=> __('Enable Slider','sprouts'),
    	'section'	=> 'sprouts-slides',
    	'priority'	=> 1,
    	)
    );
    
    $wp_customize-> add_section(
    'sprouts-slide-1', array(
    	'title'		=> __('Slide 1', 'sprouts'),
    	'panel'		=> 'sprouts-slider',
    	)
    );
    
    $wp_customize->add_setting( 
    'sprouts-slide_1', array(
    	'default'			=> '',
    	'sanitize_callback'	=> 'esc_url_raw',
    	)
     );
 
	$wp_customize->add_control(
	    new WP_Customize_Image_Control(
	        $wp_customize,
	        'sprouts-slide_1',
	        array(
	            'label' => 'Slide Upload',
	            'section' => 'sprouts-slide-1',
	            'settings' => 'sprouts-slide_1',
	        )
	    )
	);
	
	$wp_customize-> add_setting( 
	'sprouts-title-1', array(
			'default'			=> '',
			'sanitize_callback'	=> 'sprouts_sanitize_text',
			 )
	);
	
	$wp_customize-> add_control(
	'sprouts-title-1', array(
		'label'		=> __('Title','sprouts'),
		'section'	=> 'sprouts-slide-1',
		'type'		=> 'text',
		)
	);
	
	$wp_customize-> add_setting( 
	'sprouts-desc-1', array(
			'default'			=> '',
			'sanitize_callback'	=> 'sprouts_sanitize_text',
			 )
	);
	
	$wp_customize-> add_control(
	'sprouts-desc-1', array(
		'label'		=> __('Description','sprouts'),
		'section'	=> 'sprouts-slide-1',
		'type'		=> 'text',
		)
	);
	
	$wp_customize-> add_section(
    'sprouts-slide-2', array(
    	'title'		=> __('Slide 2', 'sprouts'),
    	'panel'		=> 'sprouts-slider',
    	)
    );
    
	$wp_customize->add_setting( 
    'sprouts-slide_2', array(
    	'default'			=> '',
    	'sanitize_callback'	=> 'esc_url_raw',
    	)
     );
 
	$wp_customize->add_control(
	    new WP_Customize_Image_Control(
	        $wp_customize,
	        'sprouts-slide_2',
	        array(
	            'label' => 'Slide Upload',
	            'section' => 'sprouts-slide-2',
	            'settings' => 'sprouts-slide_2',
	        )
	    )
	);
	
	$wp_customize-> add_setting( 
	'sprouts-title-2', array(
			'default'			=> '',
			'sanitize_callback'	=> 'sprouts_sanitize_text',
			 )
	);
	
	$wp_customize-> add_control(
	'sprouts-title-2', array(
		'label'		=> __('Title','sprouts'),
		'section'	=> 'sprouts-slide-2',
		'type'		=> 'text',
		)
	);
	
	$wp_customize-> add_setting( 
	'sprouts-desc-2', array(
			'default'			=> '',
			'sanitize_callback'	=> 'sprouts_sanitize_text',
			 )
	);
	
	$wp_customize-> add_control(
	'sprouts-desc-2', array(
		'label'		=> __('Description','sprouts'),
		'section'	=> 'sprouts-slide-2',
		'type'		=> 'text',
		)
	);
	
	$wp_customize-> add_section(
    'sprouts-slide-3', array(
    	'title'		=> __('Slide 3', 'sprouts'),
    	'panel'		=> 'sprouts-slider',
    	)
    );
    
	$wp_customize->add_setting( 
    'sprouts-slide_3', array(
    	'default'			=> '',
    	'sanitize_callback'	=> 'esc_url_raw',
    	)
     );
 
	$wp_customize->add_control(
	    new WP_Customize_Image_Control(
	        $wp_customize,
	        'sprouts-slide_3',
	        array(
	            'label' => 'Slide Upload',
	            'section' => 'sprouts-slide-3',
	            'settings' => 'sprouts-slide_3',
	        )
	    )
	);
	
	$wp_customize-> add_setting( 
	'sprouts-title-3', array(
			'default'			=> '',
			'sanitize_callback'	=> 'sprouts_sanitize_text',
			 )
	);
	
	$wp_customize-> add_control(
	'sprouts-title-3', array(
		'label'		=> __('Title','sprouts'),
		'section'	=> 'sprouts-slide-3',
		'type'		=> 'text',
		)
	);
	
	$wp_customize-> add_setting( 
	'sprouts-desc-3', array(
			'default'			=> '',
			'sanitize_callback'	=> 'sprouts_sanitize_text',
			 )
	);
	
	$wp_customize-> add_control(
	'sprouts-desc-3', array(
		'label'		=> __('Description','sprouts'),
		'section'	=> 'sprouts-slide-3',
		'type'		=> 'text',
		)
	);
	
	class Custom_CSS_Control extends WP_Customize_Control {
    public $type = 'textarea';
 
    public function render_content() {
        ?>
            <label>
                <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
                <textarea rows="8" style="width:100%;background: black; color: white;" <?php $this->link(); ?>><?php echo esc_textarea( $this->value() ); ?></textarea>
            </label>
        <?php
    }
}

	$wp_customize-> add_section(
    'sprouts-custom-css',
    array(
    	'title'			=> __('Custom CSS','sprouts'),
    	'description'	=> __('Add some custom CSS code to edit your theme.','sprouts'),
    	'priority'		=> 10,
    	)
    );
	$wp_customize->add_setting(
	'sprouts-css',
	array(
		'default'		=> '',
		'sanitize_callback'	=> 'sprouts_sanitize_text'
		)
	);
 
	$wp_customize->add_control(
	    new Custom_CSS_Control(
	        $wp_customize,
	        'sprouts-css',
	        array(
	            'label' => 'CSS',
	            'section' => 'sprouts-custom-css',
	            'settings' => 'sprouts-css'
	        )
	    )
	);
	
	$wp_customize-> add_section(
    'sprouts-pro',
    array(
    	'title'			=> __('GO PRO !!!','sprouts'),
    	'description'	=> __('You can now upgrade to Sprouts Plus and enjoy some awesome features of the theme along with dedicated support for it. <br><br>The pro version is available at only $25.<br><br><b>To purchase the Pro version, go <a href="http://www.divjot.co/product/sprouts-plus">here</a>.</b>.<br><br>If you are enjoying working with this theme, kindly leave it a review at <a href="https://www.wordpress.org/themes/sprouts">https://www.wordpress.org/themes/sprouts</a>','sprouts'),
    	'priority'		=> 999,
    	)
    );
    
    class sprouts_Customize_Control extends WP_Customize_Control {    
	    public function render_content() {
	        ?>
	        <label>
						<input type="checkbox" value="<?php echo esc_attr( $this->value() ); ?>" <?php $this->link(); checked( $this->value() ); ?> />
						<?php echo esc_html( $this->label ); ?>
						<?php if ( ! empty( $this->description ) ) : ?>
							<span class="description customize-control-description"><?php echo $this->description; ?></span>
						<?php endif; ?>
					</label>
					
					<script>
					jQuery(function($){
						$( '#customize-control-pro_hide' ).hide();
						$( '#accordion-section-klean_pro #accordion-section-title' ).css({"color":"#fff"});						
					});
					</script>

					
	        <?php
	    }
	}
    
    $wp_customize->add_setting(
	'pro_hide',
	array(
		'default'			=> false,
		'sanitize_callback'	=> 'sprouts_sanitize_checkbox',
		)
	);
 
	$wp_customize-> add_control( new sprouts_Customize_Control( $wp_customize,
    'pro_hide',
    array(
    	'type'		=> 'checkbox',
    	'label'		=> __('Hide this section forever.','sprouts'),
    	'section'	=> 'sprouts-pro',
    	'priority'	=> 1,
    	/* 'active_callback' => 'is_front_page', */
    	)
    ));
	
	function sprouts_sanitize_text( $t ) {
    return wp_kses_post( force_balance_tags( $t ) );
    }
    
    function sprouts_sanitize_checkbox( $i ) {
	    if ( $i == 1 ) {
	        return 1;
	    } 
	    else {
	        return '';
	    }
	 }
}

add_action('customize_register', 'sprouts_customizer');


function sprouts_fonts_url() {
    $fonts_url = '';
    
    $open_sans = _x('on', 'Open Sans font: on or off', 'sprouts');

	if ( 'off' !== $open_sans) {
	    $font_families = array();
	
	    if ('off' !== $open_sans ) {
		    $font_families[] = 'Open Sans:300,400,700,800';
	    }
		$query_args = array(
		    'family' => urlencode( implode( '|', $font_families ) ),
		    'subset' => urlencode( 'latin,latin-ext' ),
		);
	}
	
	$fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
 
    return $fonts_url;
}


/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function sprouts_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Primary Sidebar', 'sprouts' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Sidebar 1', 'sprouts' ),
		'id'            => 'sidebar-2',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Sidebar 2', 'sprouts' ),
		'id'            => 'sidebar-3',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Sidebar 3', 'sprouts' ),
		'id'            => 'sidebar-4',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Sidebar 4', 'sprouts' ),
		'id'            => 'sidebar-5',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
}
add_action( 'widgets_init', 'sprouts_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function sprouts_scripts() {
	wp_enqueue_style( 'sprouts-style', get_stylesheet_uri() );
	
	wp_enqueue_style('sprouts-bootstrap-style',get_template_directory_uri()."/assets/bootstrap/css/bootstrap.min.css", array('sprouts-style'));
	
	wp_enqueue_style('sprouts-main-skin',get_template_directory_uri()."/assets/css/main.css", array('sprouts-bootstrap-style'));
	
	wp_enqueue_style('sprouts-font-awesome',get_template_directory_uri()."/assets/font-awesome/css/font-awesome.min.css", array('sprouts-main-skin'));
	
	wp_enqueue_style('bx-slider-default-theme-skin', get_template_directory_uri(). "/assets/slider/jquery.bxslider.css", array('sprouts-font-awesome'));
	
	wp_enqueue_style('sprouts-nav', get_template_directory_uri(). "/assets/slicknav.css", array('bx-slider-default-theme-skin'));
	
	wp_enqueue_script('jquery');
	
	wp_enqueue_script( 'sprouts-slider-js', get_template_directory_uri() . '/js/jquery.bxslider.min.js', array(), true );
	
	wp_enqueue_script( 'sprouts-nav-js', get_template_directory_uri() . '/js/jquery.slicknav.min.js', array(), true );

	wp_enqueue_script( 'sprouts-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );

	wp_enqueue_script( 'sprouts-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'sprouts_scripts' );

function sprouts_initialize_header() {

	echo "<script>"; ?>
	
		jQuery(document).ready(function(){
		  jQuery('.bxslider').bxSlider({
		  auto: false,
		  mode: 'fade',
		  adaptiveHeight: true,
		  captions: true
		 });
		});	
		
	<?php
	
	echo "</script>";
	
	echo "<style>";
	
	echo get_theme_mod('sprouts-css');
	
	echo "</style>";
	
} 

add_action('wp_head', 'sprouts_initialize_header');

/**
 * Implement the Custom Header feature.
 */
//require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
